@@ -14,9 +14,9 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: GtkNSSDialogs.cpp,v 1.49 2006/12/04 22:10:37 chpe Exp $
+ *  $Id: GtkNSSDialogs.cpp 7275 2007-08-15 08:04:05Z diegoe $
  */
 
 /*
@@ -86,6 +86,7 @@
 #include "ephy-file-helpers.h"
 #include "ephy-gui.h"
 #include "ephy-password-dialog.h"
+#include "ephy-stock-icons.h"
 
 #include "AutoJSContextStack.h"
 #include "AutoWindowModalState.h"
@@ -253,7 +254,7 @@ display_cert_warning_box (nsIInterfaceRequestor *ctx,
 	}
 
 	gtk_dialog_set_has_separator (GTK_DIALOG (dialog), FALSE);
-	gtk_window_set_icon_name (GTK_WINDOW (dialog), "web-browser");
+	gtk_window_set_icon_name (GTK_WINDOW (dialog), EPHY_STOCK_EPHY);
 
 	higgy_setup_dialog (GTK_DIALOG (dialog), 
 			    GTK_STOCK_DIALOG_WARNING, &label, &vbox);
@@ -262,7 +263,7 @@ display_cert_warning_box (nsIInterfaceRequestor *ctx,
 	gtk_dialog_add_button (GTK_DIALOG (dialog), _("_View Certificate"),
 			       NSSDIALOG_RESPONSE_VIEW_CERT);
 
-	gtk_dialog_add_button (GTK_DIALOG (dialog), GTK_STOCK_CANCEL,
+	button = gtk_dialog_add_button (GTK_DIALOG (dialog), GTK_STOCK_CANCEL,
 			       GTK_RESPONSE_CANCEL);
 
 	if (affirmative_text == NULL)
@@ -270,10 +271,9 @@ display_cert_warning_box (nsIInterfaceRequestor *ctx,
 		affirmative_text = _("_Accept");
 	}
 
-	button = gtk_dialog_add_button (GTK_DIALOG (dialog), 
-					affirmative_text,
+	gtk_dialog_add_button (GTK_DIALOG (dialog), affirmative_text,
 					GTK_RESPONSE_ACCEPT);
-	gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_ACCEPT);
+	gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_CANCEL);
 
         if (checkbox_text)
 	{
@@ -292,7 +292,7 @@ display_cert_warning_box (nsIInterfaceRequestor *ctx,
 	gtk_widget_grab_focus (button);
 
 	gtk_label_set_markup (GTK_LABEL (label), markup_text);
-	gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_ACCEPT);
+	gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_CANCEL);
 	gtk_widget_show_all (dialog);
 
 	while (1)
@@ -591,7 +591,7 @@ GtkNSSDialogs::NotifyCrlNextupdate (nsIInterfaceRequestor *ctx,
 			   "needs to be updated.\n\n"
 			   "Please ask your system administrator for assistance."),
 			 NS_ConvertUTF16toUTF8 (commonName).get ());
-	gtk_window_set_icon_name (GTK_WINDOW (dialog), "web-browser");
+	gtk_window_set_icon_name (GTK_WINDOW (dialog), EPHY_STOCK_EPHY);
 
 	g_signal_connect (dialog, "response",
 			  (GCallback) gtk_widget_destroy, NULL);
@@ -633,11 +633,11 @@ GtkNSSDialogs::ConfirmDownloadCACert(nsIInterfaceRequestor *ctx,
 					     GTK_WINDOW (dialog));
 	}
 
-	gtk_window_set_icon_name (GTK_WINDOW (dialog), "web-browser");
+	gtk_window_set_icon_name (GTK_WINDOW (dialog), EPHY_STOCK_EPHY);
 
 	higgy_setup_dialog (GTK_DIALOG (dialog), GTK_STOCK_DIALOG_WARNING,
 			    &label, NULL);
-	gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_ACCEPT);
+	gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_CANCEL);
 
 	nsString commonName;
 	cert->GetCommonName (commonName);
@@ -714,7 +714,7 @@ GtkNSSDialogs::NotifyCACertExists (nsIInterfaceRequestor *ctx)
 					     GTK_WINDOW (dialog));
 	}
 
-	gtk_window_set_icon_name (GTK_WINDOW (dialog), "web-browser");
+	gtk_window_set_icon_name (GTK_WINDOW (dialog), EPHY_STOCK_EPHY);
 
 	higgy_setup_dialog (GTK_DIALOG (dialog), GTK_STOCK_DIALOG_ERROR,
 			    &label, NULL);
@@ -882,7 +882,7 @@ GtkNSSDialogs::CrlImportStatusDialog(nsIInterfaceRequestor *ctx, nsICRLInfo *crl
 					      GTK_STOCK_OK, GTK_RESPONSE_OK,
 					      (char *) NULL);
 
-	gtk_window_set_icon_name (GTK_WINDOW (dialog), "web-browser");
+	gtk_window_set_icon_name (GTK_WINDOW (dialog), EPHY_STOCK_EPHY);
 	gtk_window_set_title (GTK_WINDOW (dialog), _("Certificate Revocation List Imported"));
 
 	/* Needed because gparent == NULL always because of mozilla sucks */
@@ -1229,7 +1229,7 @@ GtkNSSDialogs::ViewCert(nsIInterfaceRequestor *ctx,
 		gtk_window_set_destroy_with_parent (GTK_WINDOW (dialog), TRUE);
 	}
 
-	gtk_window_set_icon_name (GTK_WINDOW (dialog), "web-browser");
+	gtk_window_set_icon_name (GTK_WINDOW (dialog), EPHY_STOCK_EPHY);
 
 	gtk_window_set_title (GTK_WINDOW (dialog), _("Certificate Properties"));
 	gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_CLOSE);
@@ -1512,6 +1512,10 @@ GtkNSSDialogs::GetPassword(nsIInterfaceRequestor *aCtx,
 				 flags);
 	EphyPasswordDialog *password_dialog = EPHY_PASSWORD_DIALOG (dialog);
 
+	/* Translators: A "token" is something that enables the user to authenticate himself or
+         * prove his credentials. This can be either a hardware device (e.g. a smart-card), or
+         * a data file (e.g. a cryptographic certificate).
+         */
 	char *message = g_markup_printf_escaped (_("Please enter the password for the “%s” token"),
 						 NS_ConvertUTF16toUTF8 (aTokenName).get ());
 	gtk_message_dialog_set_markup (GTK_MESSAGE_DIALOG (dialog),
@@ -1580,7 +1584,7 @@ GtkNSSDialogs::ChooseToken (nsIInterfaceRequestor *aContext,
 		   GTK_BUTTONS_CANCEL,
 		   _("Please select a token:"));
 
-  gtk_window_set_icon_name (GTK_WINDOW (dialog), "web-browser");
+  gtk_window_set_icon_name (GTK_WINDOW (dialog), EPHY_STOCK_EPHY);
 
   GtkWidget *combo = gtk_combo_box_new_text ();
   for (PRUint32 i = 0; i < count; ++i) {
@@ -1667,7 +1671,7 @@ GtkNSSDialogs::ConfirmKeyEscrow (nsIX509Cert *aEscrowAuthority,
        "It is strongly recommended not to allow it."),
      NS_ConvertUTF16toUTF8 (commonName).get ());
 
-  gtk_window_set_icon_name (GTK_WINDOW (dialog), "web-browser");
+  gtk_window_set_icon_name (GTK_WINDOW (dialog), EPHY_STOCK_EPHY);
 
   GtkWidget *button = gtk_dialog_add_button (GTK_DIALOG (dialog),
 					     _("_Reject"),
