@@ -14,9 +14,9 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: ephy-location-action.c,v 1.50 2006/12/18 12:35:02 chpe Exp $
+ *  $Id: ephy-location-action.c 7020 2007-05-01 17:13:10Z xan $
  */
 
 #include "config.h"
@@ -370,7 +370,8 @@ connect_proxy (GtkAction *action, GtkWidget *proxy)
 						    EPHY_COMPLETION_KEYWORDS_COL,
 						    EPHY_COMPLETION_RELEVANCE_COL,
 						    EPHY_COMPLETION_EXTRA_COL,
-						    EPHY_COMPLETION_FAVICON_COL);
+						    EPHY_COMPLETION_FAVICON_COL,
+						    EPHY_COMPLETION_URL_COL);
 
 		add_completion_actions (action, proxy);
 
